#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var chalk_1 = __importDefault(require("chalk"));
var commander_1 = __importDefault(require("commander"));
var update_notifier_1 = __importDefault(require("update-notifier"));
// eslint-disable-next-line import/order
var index_1 = require("./index");
// eslint-disable-next-line @typescript-eslint/no-var-requires
var pkg = require('../package.json');
// Notify for updates
if (pkg.version) {
    update_notifier_1.default({ pkg: pkg }).notify();
}
// base
commander_1.default
    .version(pkg.version || 'dev')
    .requiredOption('-c, --connection <connection>', 'Set connection string')
    .option('-d, --delay <delay>', 'Set delay in seconds', function (v) { return Number.parseInt(v, 10); }, 3)
    .option('-t, --timeout <timeout>', 'Set timeout in seconds', function (v) { return Number.parseInt(v, 10); }, 60);
// process args
commander_1.default.parse(process.argv);
// run
console.log(chalk_1.default.white.bold("await pg") + " " + chalk_1.default.gray("(" + (pkg.version || 'dev') + ")"));
var _a = commander_1.default.opts(), connectionString = _a.connection, delay = _a.delay, timeout = _a.timeout;
index_1.awaitReadyDatabase({
    connectionString: connectionString,
    delay: delay,
    timeout: timeout,
}).then(function () {
    console.log("" + chalk_1.default.green("connection established"));
    process.exit(0);
}).catch(function (e) {
    if (e === 'timeout') {
        console.log("" + chalk_1.default.red("connection timed out after " + timeout + " seconds"));
    }
    else {
        console.log(e);
    }
    process.exit(1);
});
//# sourceMappingURL=cli.js.map